@@ -32,16 +32,14 @@
 /* ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE */
 /* POSSIBILITY OF SUCH DAMAGE. */
 
+#include <stddef.h>
 #include "kgrid.h"
 
 static void get_all_grid_addresses(int grid_address[][3], const int mesh[3]);
-/* static int get_grid_point_double_mesh(const int address_double[3], */
-/*                                       const int mesh[3]); */
-/* static int get_grid_point_single_mesh(const int address[3], const int mesh[3]); */
-static long get_long_grid_point_double_mesh(const int address_double[3],
-                                            const int mesh[3]);
-static long get_long_grid_point_single_mesh(const int address[3],
-                                            const int mesh[3]);
+static size_t get_grid_point_double_mesh(const int address_double[3],
+                                         const int mesh[3]);
+static size_t get_grid_point_single_mesh(const int address[3],
+                                         const int mesh[3]);
 static void modulo_i3(int v[3], const int m[3]);
 static void reduce_grid_address(int address[3], const int mesh[3]);
 static void reduce_grid_address_double(int address[3], const int mesh[3]);
@@ -54,13 +52,13 @@ void kgd_get_all_grid_addresses(int grid_address[][3], const int mesh[3])
 int kgd_get_grid_point_double_mesh(const int address_double[3],
                                    const int mesh[3])
 {
-  return get_long_grid_point_double_mesh(address_double, mesh);
+  return get_grid_point_double_mesh(address_double, mesh);
 }
 
-long kgd_get_long_grid_point_double_mesh(const int address_double[3],
-                                         const int mesh[3])
+size_t kgd_get_dense_grid_point_double_mesh(const int address_double[3],
+                                            const int mesh[3])
 {
-  return get_long_grid_point_double_mesh(address_double, mesh);
+  return get_grid_point_double_mesh(address_double, mesh);
 }
 
 void kgd_get_grid_address_double_mesh(int address_double[3],
@@ -88,7 +86,7 @@ static void get_all_grid_addresses(int grid_address[][3], const int mesh[3])
       address[1] = j;
       for (k = 0; k < mesh[2]; k++) {
         address[2] = k;
-        grid_point = get_long_grid_point_single_mesh(address, mesh);
+        grid_point = get_grid_point_single_mesh(address, mesh);
         grid_address[grid_point][0] = address[0];
         grid_address[grid_point][1] = address[1];
         grid_address[grid_point][2] = address[2];
@@ -98,25 +96,8 @@ static void get_all_grid_addresses(int grid_address[][3], const int mesh[3])
   }
 }
 
-/* static int get_grid_point_double_mesh(const int address_double[3], */
-/*                                       const int mesh[3]) */
-/* { */
-/*   int i, address[3]; */
-
-/*   for (i = 0; i < 3; i++) { */
-/*     if (address_double[i] % 2 == 0) { */
-/*       address[i] = address_double[i] / 2; */
-/*     } else { */
-/*       address[i] = (address_double[i] - 1) / 2; */
-/*     } */
-/*   } */
-/*   modulo_i3(address, mesh); */
-
-/*   return get_grid_point_single_mesh(address, mesh); */
-/* } */
-
-static long get_long_grid_point_double_mesh(const int address_double[3],
-                                            const int mesh[3])
+static size_t get_grid_point_double_mesh(const int address_double[3],
+                                         const int mesh[3])
 {
   int i;
   int address[3];
@@ -130,29 +111,21 @@ static long get_long_grid_point_double_mesh(const int address_double[3],
   }
   modulo_i3(address, mesh);
 
-  return get_long_grid_point_single_mesh(address, mesh);
+  return get_grid_point_single_mesh(address, mesh);
 }
 
-static long get_long_grid_point_single_mesh(const int address[3],
-                                            const int mesh[3])
+static size_t get_grid_point_single_mesh(const int address[3],
+                                         const int mesh[3])
 {
 #ifndef GRID_ORDER_XYZ
-  return address[2] * mesh[0] * mesh[1] + address[1] * mesh[0] + address[0];
+  return (address[2] * mesh[0] * (size_t)(mesh[1])
+          + address[1] * mesh[0] + address[0]);
 #else
-  return address[0] * mesh[1] * mesh[2] + address[1] * mesh[2] + address[2];
+  return (address[0] * mesh[1] * (size_t)(mesh[2])
+          + address[1] * mesh[2] + address[2]);
 #endif
 }
 
-/* static int get_grid_point_single_mesh(const int address[3], */
-/*                                       const int mesh[3]) */
-/* { */
-/* #ifndef GRID_ORDER_XYZ */
-/*   return address[2] * mesh[0] * mesh[1] + address[1] * mesh[0] + address[0]; */
-/* #else */
-/*   return address[0] * mesh[1] * mesh[2] + address[1] * mesh[2] + address[2]; */
-/* #endif */
-/* } */
-
 static void modulo_i3(int v[3], const int m[3])
 {
   int i;
